bbprep.selectors.XCOMXSelector
==============================

.. currentmodule:: bbprep.selectors

.. autoclass:: XCOMXSelector
   :members:

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~XCOMXSelector.get_atomic_positions
      ~XCOMXSelector.select_atoms
   
   

   
   
   